declare('KombatTunes', KombatTunes or {})
KombatTunes.version = 1.2
math.randomseed( os.time() )
KombatTunes.musictimer = Timer()
KombatTunes.playing = false
KombatTunes.announce = false
KombatTunes.audio_path = "plugins/kombattunes/audio/"
KombatTunes.volume = 0.5

--load the file list
dofile("list.lua")

--load the gui
dofile("gui.lua")


--returns a random verb
function KombatTunes.verb()
	local verb_list = {
		"launches",
		"lunges",
		"lurches",
		"leaps",
	}
	return verb_list[math.random(#verb_list)]
end
	

--starts playing a new song
--the song_request parameter is an optional regex pattern to be searched for to identify the song to play
--if omitted, a song is selected at random
function KombatTunes.new(song_request)
	KombatTunes.playing = true
	local song = nil
	if song_request == nil then
		--choose a song at random
		song = KombatTunes.tunes[math.random(#KombatTunes.tunes)]
	else
		--play the song requested
		for i,entry in pairs(KombatTunes.tunes) do
			if (string.find(string.lower(entry[1]), string.lower(song_request)) ~= nil) then
				song = entry
				break
			end
		end
	end

	--sanity check
	if song == nil then
		print("\127DD6600Unknown song: \127FFEE00"..song_request)
		KombatTunes.playing = true
		return
	end

	--start playing
	gksound.GKPlayMusic(KombatTunes.audio_path..song[1], false, true, 0, KombatTunes.volume)
	--set a timer to toggle the boolean and resume the ambient music when it finishes
	KombatTunes.musictimer:SetTimeout(song[2],function()
		gksound.GKPlayMusic("music/ambient_1.ogg")
		KombatTunes.playing = false
	end);
	
	--optionally announce to the sector what you are listening to, otherwise just print it to your own chat
	if (KombatTunes.announce) then
		SendChat("/me "..KombatTunes.verb().." into battle to the sounds of "..song[1], "SECTOR")
	else
		print("\127DD6600Now playing: \127FFEE00"..song[1])
	end
	
end


--this function plays a song if none is currently playing, otherwise does nothing
--this is a good function to integrate into a hail-sending plugin, to automatically play music when you start a fight without interrupted the current song each time you hail a new opponent
function KombatTunes.fight(data)
	if not KombatTunes.playing then
		KombatTunes.new(data)
	end
end


--process the command
function KombatTunes.proc(_,data)
	if (data == nil) then
		KombatTunes.new(nil)
	elseif (data[1] == "stop") then
		gksound.GKStopMusic()
		KombatTunes.playing = false
	elseif (data[1] == "start") then
		gksound.GKPlayMusic("music/ambient_1.ogg")
	elseif (data[1] == "gui") then
		KombatTunes.ui.show()
	else
		KombatTunes.new(data[1])
	end
end

RegisterUserCommand("kombattunes",KombatTunes.proc)
RegisterUserCommand("kt",KombatTunes.proc)